@@ -357,7 +357,7 @@ public:
 
   void GameMessageIn(int message, void* messagedata);
 
-  virtual void GameMessageOut(void* gameHelper, int message, const void* messagedata) = 0;
+  virtual void GameMessageOut(void* gameHelper, int message, const void* messagedata) {};
 
   void ScheduleRedraw() { 
     m_bRedrawScheduled = true; 
