@@ -57,7 +57,7 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
 {
  public:
 
-  CDasherModel(CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CNodeCreationManager *pNCManager, CDasherInterfaceBase *pDashIface, CDasherView *pView, int iOffset, bool bGameMode = false, const std::string &strGameModeText = "");
+  CDasherModel(CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CNodeCreationManager *pNCManager, CDasherInterfaceBase *pDashIface, CDasherView *pView, int iOffset);
   ~CDasherModel();
 
   ///
@@ -176,7 +176,7 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
   /// button mode etc.)
   ///
 
-  void ScheduleZoom(int dasherx, int dashery);
+  void ScheduleZoom(dasherint iDasherX, dasherint iDasherY);
 
   ///
   /// Return the number of remaining zoom steps
@@ -294,7 +294,7 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
 
   // Whether game mode is active
   // TODO: This isn't very functional at the moment
-  bool m_bGameMode;
+  //  bool m_bGameMode;
 
   // Whether characters entered by alphabet manager are expected to
   // require conversion.
