@@ -22,7 +22,8 @@ namespace Dasher {
 
 using namespace Dasher;
 using namespace std;
-
+/// \ingroup Input 
+/// \{
 class Dasher::CSocketInputBase : public CDasherInput {
 
 public:
@@ -95,6 +96,8 @@ public:
 
   virtual void SetRawRange(int iWhich, double dMin, double dMax);
 
+  bool GetSettings(SModuleSettings **pSettings, int *iCount);
+
 protected:
 
   myint dasherCoordinates[DASHER_SOCKET_INPUT_MAX_COORDINATE_COUNT];
@@ -128,7 +131,7 @@ protected:
   virtual void SocketDebugMsg(const char *pszFormat, ...);
   
 };
-
+/// \}
 #endif
 
 
